==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/web/ReactRewireOptions.java <==
package io.github.cdklabs.projen.web;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:29.057Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.web.ReactRewireOptions")
@software.amazon.jsii.Jsii.Proxy(ReactRewireOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface ReactRewireOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Rewire webpack configuration.
     * <p>
     * Use this property to override webpack configuration properties provided
     * by create-react-app, without needing to eject.
     * <p>
     * This property will create a <code>config-overrides.js</code> file in your root directory,
     * which will contain the desired rewiring code.
     * <p>
     * To <strong>override</strong> the configuration, you can provide simple key value pairs.
     * Keys take the form of js code directives that traverse to the desired property.
     * Values should be JSON serializable objects.
     * <p>
     * For example, the following config:
     * <p>
     * <blockquote><pre>
     * rewire: { "module.unknownContextCritical": false }
     * </pre></blockquote>
     * <p>
     * Will translate to the following <code>config-overrides.js</code> file:
     * <p>
     * <blockquote><pre>
     * module.exports = function override(config, env) {
     *    config.module.unknownContextCritical = false;
     * }
     * </pre></blockquote>
     * <p>
     * Default: - No rewired config.
     * <p>
     * @see https://github.com/timarney/react-app-rewired
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.Map<java.lang.String, java.lang.Object> getRewire() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ReactRewireOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ReactRewireOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<ReactRewireOptions> {
        java.util.Map<java.lang.String, java.lang.Object> rewire;

        /**
         * Sets the value of {@link ReactRewireOptions#getRewire}
         * @param rewire Rewire webpack configuration.
         *               Use this property to override webpack configuration properties provided
         *               by create-react-app, without needing to eject.
         *               <p>
         *               This property will create a <code>config-overrides.js</code> file in your root directory,
         *               which will contain the desired rewiring code.
         *               <p>
         *               To <strong>override</strong> the configuration, you can provide simple key value pairs.
         *               Keys take the form of js code directives that traverse to the desired property.
         *               Values should be JSON serializable objects.
         *               <p>
         *               For example, the following config:
         *               <p>
         *               <blockquote><pre>
         *               rewire: { "module.unknownContextCritical": false }
         *               </pre></blockquote>
         *               <p>
         *               Will translate to the following <code>config-overrides.js</code> file:
         *               <p>
         *               <blockquote><pre>
         *               module.exports = function override(config, env) {
         *                  config.module.unknownContextCritical = false;
         *               }
         *               </pre></blockquote>
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder rewire(java.util.Map<java.lang.String, ? extends java.lang.Object> rewire) {
            this.rewire = (java.util.Map<java.lang.String, java.lang.Object>)rewire;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ReactRewireOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public ReactRewireOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ReactRewireOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ReactRewireOptions {
        private final java.util.Map<java.lang.String, java.lang.Object> rewire;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.rewire = software.amazon.jsii.Kernel.get(this, "rewire", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.Object.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.rewire = (java.util.Map<java.lang.String, java.lang.Object>)builder.rewire;
        }

        @Override
        public final java.util.Map<java.lang.String, java.lang.Object> getRewire() {
            return this.rewire;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getRewire() != null) {
                data.set("rewire", om.valueToTree(this.getRewire()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.web.ReactRewireOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ReactRewireOptions.Jsii$Proxy that = (ReactRewireOptions.Jsii$Proxy) o;

            return this.rewire != null ? this.rewire.equals(that.rewire) : that.rewire == null;
        }

        @Override
        public final int hashCode() {
            int result = this.rewire != null ? this.rewire.hashCode() : 0;
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/web/ReactRewireOptions.java <==
package io.github.cdklabs.projen.web;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.746Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.web.ReactRewireOptions")
@software.amazon.jsii.Jsii.Proxy(ReactRewireOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface ReactRewireOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Rewire webpack configuration.
     * <p>
     * Use this property to override webpack configuration properties provided
     * by create-react-app, without needing to eject.
     * <p>
     * This property will create a <code>config-overrides.js</code> file in your root directory,
     * which will contain the desired rewiring code.
     * <p>
     * To <strong>override</strong> the configuration, you can provide simple key value pairs.
     * Keys take the form of js code directives that traverse to the desired property.
     * Values should be JSON serializable objects.
     * <p>
     * For example, the following config:
     * <p>
     * <blockquote><pre>
     * rewire: { "module.unknownContextCritical": false }
     * </pre></blockquote>
     * <p>
     * Will translate to the following <code>config-overrides.js</code> file:
     * <p>
     * <blockquote><pre>
     * module.exports = function override(config, env) {
     *   config.module.unknownContextCritical = false;
     * }
     * </pre></blockquote>
     * <p>
     * Default: - No rewired config.
     * <p>
     * @see <a href="https://github.com/timarney/react-app-rewired">https://github.com/timarney/react-app-rewired</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.Map<java.lang.String, java.lang.Object> getRewire() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ReactRewireOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ReactRewireOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<ReactRewireOptions> {
        java.util.Map<java.lang.String, java.lang.Object> rewire;

        /**
         * Sets the value of {@link ReactRewireOptions#getRewire}
         * @param rewire Rewire webpack configuration.
         *               Use this property to override webpack configuration properties provided
         *               by create-react-app, without needing to eject.
         *               <p>
         *               This property will create a <code>config-overrides.js</code> file in your root directory,
         *               which will contain the desired rewiring code.
         *               <p>
         *               To <strong>override</strong> the configuration, you can provide simple key value pairs.
         *               Keys take the form of js code directives that traverse to the desired property.
         *               Values should be JSON serializable objects.
         *               <p>
         *               For example, the following config:
         *               <p>
         *               <blockquote><pre>
         *               rewire: { "module.unknownContextCritical": false }
         *               </pre></blockquote>
         *               <p>
         *               Will translate to the following <code>config-overrides.js</code> file:
         *               <p>
         *               <blockquote><pre>
         *               module.exports = function override(config, env) {
         *                 config.module.unknownContextCritical = false;
         *               }
         *               </pre></blockquote>
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder rewire(java.util.Map<java.lang.String, ? extends java.lang.Object> rewire) {
            this.rewire = (java.util.Map<java.lang.String, java.lang.Object>)rewire;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ReactRewireOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public ReactRewireOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ReactRewireOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ReactRewireOptions {
        private final java.util.Map<java.lang.String, java.lang.Object> rewire;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.rewire = software.amazon.jsii.Kernel.get(this, "rewire", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.Object.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.rewire = (java.util.Map<java.lang.String, java.lang.Object>)builder.rewire;
        }

        @Override
        public final java.util.Map<java.lang.String, java.lang.Object> getRewire() {
            return this.rewire;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getRewire() != null) {
                data.set("rewire", om.valueToTree(this.getRewire()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.web.ReactRewireOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ReactRewireOptions.Jsii$Proxy that = (ReactRewireOptions.Jsii$Proxy) o;

            return this.rewire != null ? this.rewire.equals(that.rewire) : that.rewire == null;
        }

        @Override
        public final int hashCode() {
            int result = this.rewire != null ? this.rewire.hashCode() : 0;
            return result;
        }
    }
}
